/* SPDX-License-Identifier: (GPL-2.0-only OR BSD-2-Clause) */

#ifndef _DT_BINDINGS_ADI_AD4695_H
#define _DT_BINDINGS_ADI_AD4695_H

#define AD4695_COMMON_MODE_REFGND	0xFF
#define AD4695_COMMON_MODE_COM		0xFE

#endif /* _DT_BINDINGS_ADI_AD4695_H */
