/* SPDX-License-Identifier: GPL-2.0 */
/*
 * Copyright (C) 2019 The Linux Foundation. All rights reserved.
 */

#ifndef __DT_BINDINGS_INTERCONNECT_QCOM_OSM_L3_H
#define __DT_BINDINGS_INTERCONNECT_QCOM_OSM_L3_H

#define MASTER_OSM_L3_APPS	0
#define SLAVE_OSM_L3		1

#define MASTER_EPSS_L3_APPS	0
#define SLAVE_EPSS_L3_SHARED	1

#endif
